@@ -118,17 +118,10 @@ add_cb (GtkWidget *widget, GSnes9xData *gsnes_data)
 	GtkWidget   *label;
 	GtkWidget   *text;
 	GtkWidget   *frame;
-	GlobalPrefs *prefs = g_new (GlobalPrefs, 1);
 	gchar       *path;
-
+	gchar       *imagepath;
 
 	F_NAME();
-
-	prefs = read_conf_file ();	
-	path = prefs->string_prefs[ROMS_DIR-ROM_STR_PREFS];
-	g_free (prefs);
-	if (!path)
-		path = get_default_roms_dir();
 	
 	addrom_info->data       = gsnes_data;
 	gsnes_data->dialog_open = TRUE;
@@ -170,6 +163,7 @@ add_cb (GtkWidget *widget, GSnes9xData *gsnes_data)
 	gtk_widget_show (label);
 	
 	text   = gnome_file_entry_new(NULL, _("Select ROM file"));
+	path = get_default_roms_dir();
 	gnome_file_entry_set_default_path (GNOME_FILE_ENTRY(text), path);
 	gtk_table_attach (GTK_TABLE (table), text, 1, 2, 0, 1,
 			  GTK_FILL, GTK_FILL, 5, 2);
@@ -218,7 +212,8 @@ add_cb (GtkWidget *widget, GSnes9xData *gsnes_data)
 	gtk_widget_show (label);
 	
 	text   = gnome_file_entry_new(NULL, _("Select Image file"));
-	gnome_file_entry_set_default_path (GNOME_FILE_ENTRY(text), path);
+	imagepath = get_default_images_dir();
+	gnome_file_entry_set_default_path (GNOME_FILE_ENTRY(text), imagepath);
 	gtk_table_attach (GTK_TABLE (table), text, 1, 2, 2, 3,
 			  GTK_FILL, GTK_FILL, 5, 2);
 	gtk_widget_show (text);
@@ -307,116 +302,18 @@ quit_by_menu_cb (GtkWidget *widget, GSnes9xData *gsnes_data)
 void
 readme_cb (GtkWidget *widget, gint part)
 {
-	GtkWidget *readme = NULL;
-	GtkWidget *text;
-	GtkWidget *hbox;
-	GtkWidget *vscrollbar;
-	
-#include "doc.h" /* Nasty, nasty. */
+	GnomeHelpMenuEntry help_ref;	
 
-	F_NAME();
+	help_ref.name = "GSnes9x";
 	
-	hbox       = gtk_hbox_new (FALSE, 0);
-	text       = gtk_text_new (NULL, NULL);	
-	vscrollbar = gtk_vscrollbar_new (GTK_TEXT(text)->vadj);
+	if (part < 7)	
+		help_ref.path = g_strdup_printf ("readme-snes9x.html#%d", part);
+	else 
+		help_ref.path = g_strdup_printf ("help-2.html#%d", part);
 	
-	gtk_box_pack_start (GTK_BOX (hbox), text, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (hbox), vscrollbar, FALSE, FALSE, 0);
-
-	switch (part) {
-	case 0:
-		readme = gnome_dialog_new (_("Snes9X Original README.TXT"),
-					   GNOME_STOCK_BUTTON_OK, NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readme1, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmeinfo, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmegraph, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmesound, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmecheat, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmespeed, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmeformat, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmejoystick, -1);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readme2, -1);
-		break;
-	case 1:
-		readme = gnome_dialog_new (_("GSnes9x Info Options Help"),
-					   GNOME_STOCK_BUTTON_OK, NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmeinfo, -1);
-		break;
-	case 2:
-		readme = gnome_dialog_new (_("GSnes9x Graphics Options Help"),
-					   GNOME_STOCK_BUTTON_OK, NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmegraph, -1);
-		break;
-	case 3:
-		readme = gnome_dialog_new (_("GSnes9x Sound Options Help"),
-					   GNOME_STOCK_BUTTON_OK, NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmesound, -1);
-		break;
-	case 4:
-		readme = gnome_dialog_new (_("GSnes9x Cheat Codes Options "
-					     "Help"), GNOME_STOCK_BUTTON_OK,
-					   NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmecheat, -1);
-		break;
-	case 5:
-		readme = gnome_dialog_new (_("GSnes9x Speed Up/Down Options "
-					     "Help"), GNOME_STOCK_BUTTON_OK,
-					   NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmespeed, -1);
-		break;
-	case 6:
-		readme = gnome_dialog_new (_("GSnes9x ROM Image Format Options"
-					   "Help"), GNOME_STOCK_BUTTON_OK,
-					   NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmeformat, -1);
-		break;
-	case 7:
-		readme = gnome_dialog_new (_("GSnes9x Joystick Options Help"),
-					   GNOME_STOCK_BUTTON_OK, NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmejoystick, -1);
-		break;
-	case 8:
-		readme = gnome_dialog_new (_("GSnes9x System Options Help"),
-					   GNOME_STOCK_BUTTON_OK, NULL);
-		gtk_text_insert (GTK_TEXT (text), NULL,
-				 NULL, NULL, readmesystem, -1);
-	}
-	
-	gtk_text_set_editable (GTK_TEXT (text), FALSE);
-	
-	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (readme)->vbox),
-			    hbox, FALSE, FALSE, 10);
-
-	gtk_widget_set_usize (text, 500, 300);
-
-	gnome_dialog_button_connect (GNOME_DIALOG (readme),
-				     0, GTK_SIGNAL_FUNC (destroy_data_cb),
-				     (gpointer) readme);
-
-	gtk_window_set_modal (GTK_WINDOW (readme), TRUE);
-	
-	gtk_widget_show (vscrollbar);
-	gtk_widget_show (text);
-	gtk_widget_show (hbox);
-	gtk_widget_show (readme);
+	gnome_help_display (NULL, &help_ref);
 }
-
+	
 void
 about_cb (GtkWidget *widget, GSnes9xData *gsnes_data)
 {
