@@ -218,6 +218,8 @@ rom_prefs_info_ops (ROMPrefsData *rpd)
 	GtkWidget *text;
 	GtkWidget *separator;
 	GtkWidget *button;
+	gchar     *path;
+	gchar     *imagepath;
 
 
 	F_NAME();
@@ -230,9 +232,12 @@ rom_prefs_info_ops (ROMPrefsData *rpd)
 			  GTK_FILL, GTK_FILL, 5, 2);
 	gtk_widget_show (label);
 
-	text = gnome_file_entry_new (NULL, _("Select ROM file"));
+
+	text   = gnome_file_entry_new(NULL, _("Select ROM file"));
+	path = get_default_roms_dir();
+	gnome_file_entry_set_default_path (GNOME_FILE_ENTRY(text), path);
 	gtk_table_attach (GTK_TABLE (table), text, 1, 2, 0, 1,
-			  GTK_FILL, GTK_FILL, 5, 2);
+			  GTK_FILL, GTK_FILL, 5, 2);	
 	gtk_widget_show (text);
 	rpd->entry[ROM_FILE] =  gnome_file_entry_gtk_entry(
 			GNOME_FILE_ENTRY(text));
@@ -267,7 +272,9 @@ rom_prefs_info_ops (ROMPrefsData *rpd)
 			  GTK_FILL, GTK_FILL, 5, 2);
 	gtk_widget_show (label);
 
-	text = gnome_file_entry_new (NULL, _("Select Image file"));
+	text   = gnome_file_entry_new(NULL, _("Select Image file"));
+	imagepath = get_default_images_dir();
+	gnome_file_entry_set_default_path (GNOME_FILE_ENTRY(text), imagepath);
 	gtk_table_attach (GTK_TABLE (table), text, 1, 2, 3, 4,
 			  GTK_SHRINK, GTK_SHRINK, 5, 2);
 	gtk_widget_show (text);
@@ -1752,10 +1759,13 @@ void
 rom_prefs_help_cb (GtkWidget *widget, GtkWidget *notebook)
 {
 	gint part;
+	gint page[] = { 7, 1, 2, 3, 4, 5, 6 };
 	
 	F_NAME();
 	
-	part = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook))+1;
+	part = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+
+	part = page[part];
 
 	readme_cb (NULL, part);
 }
